clear; %clc;

path(path,'./MlabFunctions'); % Bios Server

%% set some constants and hyperparameters
r = 2;  % rank of low-rank matrix
MCMCpara.nBurnin = 1e3; % number of burn-in samples
MCMCpara.nCollect = 1e3; % number of samples after burn-in
MCMCpara.a0 = 1e-6; % page 980, 1st gamma hyperparameter of tau_delta
MCMCpara.b0 = 1e-6; % page 980, 2nd gamma hyperparameter of tau_delta
MCMCpara.c0 = 1e-6; % page 980, 1st gamma hyperparameter of tau_u
MCMCpara.d0 = 1e-6; % page 980, 2nd gamma hyperparameter of tau_u
MCMCpara.e0 = 1e-6; % page 980, 1st gamma hyperparameter of tau_v,d
MCMCpara.f0 = 1e-6; % page 980, 2nd gamma hyperparameter of tau_v,d
MCMCpara.g0 = 1e-6; % 1st gamma hyperparameter, for the precision of the prior of B_p in equation (5)
MCMCpara.h0 = 1e-6; % 2nd gamma hyperparameter, for the precision of the prior of B_p in equation (5)
OutputFileName = 'Result';  %filename of output mat and csv file

%% input files

Y0 = dlmread('data/ROIs.csv',',');  % dependent variables, a matrix, number of subjects times number of variables
X =  dlmread('data/SNPs1.csv',',');  % independent variables with low-rank coefficient matrix, a matrix, number of subjects times number of variables
W = dlmread('data/Covariates.csv',','); % other independent variables, a matrix, number of subjects times number of variables

n = size(Y0,1);
p = size(X,2);
q = size(W,2);


%% RUN LGLRR %%
TypeCov='Factor'; % Wish, Diag, Factor, default is iid
%t0 = cputime; % track time

tic
Output = GLRRadj(X,W,Y0,n,r,MCMCpara,TypeCov); %Wish, Diag, Factor, iid(default)
toc

Bh = Output.PostB;
Gh = Output.PostG;
q = size(Gh,1); 
Yh = X*Bh + W*Gh ;% + W*B0;% + Z*b;

Perf = PerformGLRR(Y0, Yh, cov(X), r, Bh);   
%time = (cputime - t0)/60;
%disp(['Time = ', num2str(time/60), ' hours']);

%% %%%%%%% Saving %%%%%%%%%
save ([OutputFileName,'.mat'],'-struct','Output');
csvwrite([OutputFileName,'.csv'], Perf);

