function O = CovFactorLoading(Y)
%%
   [n d] = size(Y);
   k = 10; %dimension of latent factor
% --- Define hyperparameter values --- %
    %hyp=.5;
    as = 1; bs = 0.3;    % gamma hyperparameters for diagonal elements of inv(Sigma)
    df = 3;            % gamma hyperparameters for t_{ij}
    ad1 = 2; bd1 = 1;  % gamma hyperparameters for delta_1
    ad2 = 3; bd2 = 1;  % gamma hyperparameters delta_h, h >= 2
%     adf = 1; bdf = 1;      % gamma hyperparameters for ad1 and ad2 or df

    % --- Initial values --- %
    sig = gamrnd(as,1/bs,d,1);                   % diagonals of sigmainv
%     Sigma=diag(1./sig);                        % Sigma
    Lambda = zeros(d,k);                       % loadings matrix
    eta =  mvnrnd(zeros(1,k),eye(k),n);        % latent factors
%     meta = zeros(n,k);                         % eta means
%     veta = eye(k);                             % eta dispersion
    t = gamrnd(df/2,2/df,[d,k]);               % local shrinkage coefficients
    delta = [gamrnd(ad1,bd1);gamrnd(ad2,bd2,[k-1,1])]; % gobal shrinkage coefficients multilpliers
    tau = cumprod(delta);                      % global shrinkage coefficients
%     Ptht = (t .* repmat(tau',[d,1]));
    D = bsxfun(@times,t,tau');

%%
        %-----Step 1: Update Lambda-----%
        etasq = (eta'*eta);
%         Lambda = zeros(d,k);
        for j = 1:d
            Vlam1 = diag(D(j,:)) + sig(j)*etasq;
            T = cholcov(Vlam1);
            [Q,R] = qr(T);
            S = inv(R);
            Vlam = S*S';
            Elam = Vlam*sig(j)*eta'*Y(:,j);
            Lambda(j,:) = mvnrnd(Elam',Vlam);
        end
%%
        % -- Step 2: Update Sigma -- %
        sig = gamrnd(as + n/2,1./(bs+0.5*sum((Y - eta*Lambda').^2)))';
        Sigma = diag(1./sig);

        % -- Step 3: Update eta -- %
        Lmsg = bsxfun(@times,Lambda,sig);
        Veta1 = eye(k) + Lmsg'*Lambda;
        T = cholcov(Veta1);
        [Q,R] = qr(T);
        S = inv(R);
        Veta = S*S';                     % Veta = inv(Veta1)
        Meta = Y*Lmsg*Veta;
        eta = mvnrnd(Meta,Veta);        % update eta in a block
        
        %------Step 4: Update tij's = phi_ijs ----------%
        t = gamrnd(df/2 + 0.5,1./(df/2 + bsxfun(@times,Lambda.^2,tau')));

        %------Step 5: Update delta----------%
        bd = bd1 + 0.5* (1/delta(1))*sum(tau'.*(sum(t.*Lambda.^2)));
        delta(1) = gamrnd(ad1 + d*k/2, 1/bd);

        tau = cumprod(delta);
        
        tLmsq = sum(t.*Lambda.^2);
        for h = 2:k
            ad = ad2 + d*(k-h+1)/2;
            temp1 = tau'.*tLmsq;
            bd = bd2 + 0.5* (1/delta(h))*sum(temp1(h:k));
            delta(h) = gamrnd(ad,1/bd);
            tau  = cumprod(delta);
        end


        %-------update precision parameters--------%
% 
        O = inv(Lambda*Lambda' + Sigma);
%         O = (Lambda*Lambda' + Sigma);
end