clear; %clc;

Resultfile = 'Result.mat';      %mat file generated by GLRRmain.m
OutputFigDir = 'Results/';          %directory for the output files and figures
BMatlog10PThreshold = 5;    %threshold of the -log10p-values of elements in B
UMatlog10PThreshold = 4;    %threshold of the -log10p-values of elements in U
VMatlog10PThreshold = 3;    %threshold of the -log10p-values of elements in V

load(Resultfile);

%% Processing B
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Bmedian = PostB;
BsdRobust = Bsd;
pvalB = (2*(1 - normcdf(abs(Bmedian),0,BsdRobust)));
P = -log10(pvalB);


% B -log10 pvalue
figtmp=figure;
imagesc(P); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'BMatNlog10pvalue.png'));
csvwrite('BMatNlog10pvalue.csv', P);


Bbin = (P > BMatlog10PThreshold);

% B_bin -- Binary Map after thresholding
figtmp=figure;
imagesc(Bbin); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'B_bin.png'));
csvwrite('B_bin.csv', Bbin);

% B * B_bin -- B matrix after setting ``insignificant'' elements to zero
Bsp = Bmedian.*Bbin;
figtmp=figure;
imagesc(Bsp); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'BtimesB_bin.png'));
csvwrite('BtimesB_bin.csv', Bsp);

% Bbin^T * Bbin
BBbinROI = 1*Bbin'*Bbin;
figtmp=figure;
imagesc(BBbinROI); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'BbinTtimesBbin.png'));
csvwrite('BbinTtimesBbin.csv', BBbinROI);

% Bbin * Bbin^T
BBbinSNP = 1*Bbin*Bbin';
figtmp=figure;
imagesc(BBbinSNP); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'BbintimesBbinT.png'));
csvwrite('BbintimesBbinT.csv', BBbinSNP);


%% Processing U
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Umedian = median(U,3);
Umad = mad(U,1,3);
UsdRobust = Umad*1.426;
pvalU = 2*(1 - normcdf(abs(Umedian),0,Umad));
P = -log10(pvalU);

% U_Median
figtmp=figure;
imagesc(Umedian); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'U_Median.png'));


% U -log10 pvalue
figtmp=figure;
imagesc(P); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'UMatNlog10pvalue.png'));
csvwrite('UMatNlog10pvalue.csv', P);

%U_bin
Ubin = (P > UMatlog10PThreshold);
pct = sum(sum(Ubin))/(size(U,1)*size(U,2))
figtmp=figure;
imagesc(Ubin); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'U_bin.png'));
csvwrite('U_bin.csv', Ubin);

% U * U_bin -- U matrix after setting ``insignificant'' elements to zero
Usp = Umedian.*Ubin;
figtmp=figure;
imagesc(Usp); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'UtimesU_bin.png'));
csvwrite('UtimesU_bin.csv', Usp);

%% Processing V
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Vmedian = median(V,3);
Vmad = mad(V,1,3);
VsdRobust = Vmad*1.426;
pvalV = 2*(1 - normcdf(abs(Vmedian),0,Vmad));
P = -log10(pvalV);

% V_Median
figtmp=figure;
imagesc(Vmedian); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'V_Median.png'));

% V -log10 pvalue
figtmp=figure;
imagesc(P); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'VMatNlog10pvalue.png'));
csvwrite('VMatNlog10pvalue.csv', P);

%V_bin
Vbin = (P > VMatlog10PThreshold);
pct = sum(sum(Vbin))/(size(V,1)*size(V,2));
figtmp=figure;
imagesc(Vbin); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'V_bin.png'));
csvwrite('V_bin.csv', Ubin);

% V * V_bin -- V matrix after setting ``insignificant'' elements to zero
Vsp = Vmedian.*Vbin;
figtmp=figure;
imagesc(Vsp); colorbar;
print(figtmp,'-dpng',strcat(OutputFigDir,'VtimesV_bin.png'));
csvwrite('VtimesV_bin.csv', Usp);

